@@ -37,10 +37,15 @@
 #' New York: John Wiley & Sons.
 #'
 #' @return
-#' Returns an object of class \code{misty.object}, which is a list with following entries:
-#' function call (\code{call}), type of analysis \code{type}, matrix or data frame specified in
-#' \code{x} (\code{data}), specification of function arguments (\code{args}), and
-#' list with results (\code{result}).
+#' Returns an object of class \code{misty.object}, which is a list with following
+#' entries:
+#' \tabular{ll}{
+#' \code{call} \tab function call \cr
+#' \code{type} \tab type of analysis \cr
+#' \code{data} \tab matrix or data frame specified in \code{x} \cr
+#' \code{args} \tab specification of function arguments \cr
+#' \code{result} \tab result table \cr
+#' }
 #'
 #' @export
 #'
@@ -63,131 +68,104 @@
 cor.phi <- function(x, adjust = FALSE, tri = c("both", "lower", "upper"),
                     digits = 2, as.na = NULL, check = TRUE, output = TRUE) {
 
-  ####################################################################################
-  # Data
+  #_____________________________________________________________________________
+  #
+  # Initial Check --------------------------------------------------------------
 
-  #......
   # Check if input 'x' is missing
   if (isTRUE(missing(x))) { stop("Please specify a matrix or data frame for the argument 'x'.", call. = FALSE) }
 
-  #......
   # Check if input 'x' is NULL
   if (isTRUE(is.null(x))) { stop("Input specified for the argument 'x' is NULL.", call. = FALSE) }
 
-  #......
   # Matrix or data frame for the argument 'x'?
   if (isTRUE(!is.matrix(x) && !is.data.frame(x))) { stop("Please specify a matrix or data frame for the argument 'x'.", call. = FALSE) }
 
-  #-----------------------------------------
-  # As data frame
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## As data frame ####
 
   x <- as.data.frame(x, stringsAsFactors = FALSE)
 
-  #-----------------------------------------
-  # Convert user-missing values into NA
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Convert user-missing values into NA ####
 
   if (isTRUE(!is.null(as.na))) {
 
     x <- misty::as.na(x, na = as.na, check = check)
 
     # Variable with missing values only
-    x.miss <- vapply(x, function(y) all(is.na(y)), FUN.VALUE = logical(1))
-    if (isTRUE(any(x.miss))) {
-
-      stop(paste0("After converting user-mising values into NA, following variables are completely missing: ",
-                  paste(names(which(x.miss)), collapse = ", ")), call. = FALSE)
-
-    }
+    x.miss <- vapply(x, function(y) all(is.na(y)), FUN.VALUE = logical(1L))
+    if (isTRUE(any(x.miss))) { stop(paste0("After converting user-mising values into NA, following variables are completely missing: ", paste(names(which(x.miss)), collapse = ", ")), call. = FALSE) }
 
     # Constant variables
     x.zero.var <- vapply(x, function(y) length(na.omit(unique(y))) == 1L, FUN.VALUE = logical(1))
-    if (isTRUE(any(x.zero.var))) {
-
-      stop(paste0("After converting user-mising values into NA, following variables have only one unique value: ",
-                  paste(names(which(x.zero.var)), collapse = ", ")), call. = FALSE)
-
-    }
+    if (isTRUE(any(x.zero.var))) { stop(paste0("After converting user-mising values into NA, following variables have only one unique value: ", paste(names(which(x.zero.var)), collapse = ", ")), call. = FALSE) }
 
   }
 
-  ####################################################################################
-  # Input Check
+  #_____________________________________________________________________________
+  #
+  # Input Check ----------------------------------------------------------------
 
   # Check input 'check'
   if (isTRUE(!is.logical(check))) { stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE) }
 
-  #------------------------------------------
-
   if (isTRUE(check)) {
 
-    #......
     # Check input 'x'
-    if (isTRUE(any(vapply(x, function(y) any(as.numeric(y) %% 1L != 0L, na.rm = TRUE), FUN.VALUE = logical(1L))))) {
+    if (isTRUE(any(vapply(x, function(y) any(as.numeric(y) %% 1L != 0L, na.rm = TRUE), FUN.VALUE = logical(1L))))) { stop("Please specify a matrix or data frame with integer vectors for the argument 'x'.", call. = FALSE) }
 
-      stop("Please specify a matrix or data frame with integer vectors for the argument 'x'.", call. = FALSE)
-
-    }
-
-    #......
     # Check input 'x': Zero variance
     x.zero.var <- vapply(x, function(y) length(na.omit(unique(y))) == 1, FUN.VALUE = logical(1L))
     if (isTRUE(any(x.zero.var))) {
 
       if (isTRUE(length(x.zero.var) == 2L)) {
 
-        stop(paste0("Following variables in the matrix or data frame specified in 'x' have only one unique value: ",
-                   paste(names(which(x.zero.var)), collapse = ", ")), call. = FALSE)
+        stop(paste0("Following variables in the matrix or data frame specified in 'x' have only one unique value: ", paste(names(which(x.zero.var)), collapse = ", ")), call. = FALSE)
 
       } else {
 
-        warning(paste0("Following variables in the matrix or data frame specified in 'x' have only one unique value: ",
-                      paste(names(which(x.zero.var)), collapse = ", ")), call. = FALSE)
+        warning(paste0("Following variables in the matrix or data frame specified in 'x' have only one unique value: ", paste(names(which(x.zero.var)), collapse = ", ")), call. = FALSE)
       }
 
     }
 
-    #......
     # Check input 'x'
     if (isTRUE(any(vapply(x, function(y) length(na.omit(unique(y))) > 2, FUN.VALUE = logical(1L))))) {
 
-      stop("Please specify a matrix or data frame with dichotomous variables for the argument 'x'.",
-           call. = FALSE)
+      stop("Please specify a matrix or data frame with dichotomous variables for the argument 'x'.", call. = FALSE)
 
     }
 
-    #......
     # Check input 'adjust'
     if (isTRUE(!is.logical(adjust))) { stop("Please specify TRUE or FALSE for the argument 'adjust'.", call. = FALSE) }
 
-    #......
     # Check input 'tri'
-    if (isTRUE(any(!tri %in% c("both", "lower", "upper")))) { stop("Character string in the argument 'tri' does not match with \"both\", \"lower\", or \"upper\".", call. = FALSE)
+    if (isTRUE(any(!tri %in% c("both", "lower", "upper")))) { stop("Character string in the argument 'tri' does not match with \"both\", \"lower\", or \"upper\".", call. = FALSE) }
 
-    }
-
-    #......
     # Check input 'digits'
     if (isTRUE(digits %% 1L != 0L || digits < 0L)) { warning("Specify a positive integer number for the argument 'digits'.", call. = FALSE) }
 
-    #......
     # Check input 'output'
     if (isTRUE(!is.logical(output))) { stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE) }
 
   }
 
-  ####################################################################################
-  # Data and Arguments
+  #_____________________________________________________________________________
+  #
+  # Arguments ------------------------------------------------------------------
 
-  #----------------------------------------
-  # Print triangular
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Print triangular ####
 
   tri <- ifelse(all(c("both", "lower", "upper") %in% tri), "lower", tri)
 
-  ####################################################################################
-  # Main Function
+  #_____________________________________________________________________________
+  #
+  # Main Function --------------------------------------------------------------
 
-  #----------------------------------------
-  # Two variables
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Two variables ####
 
   if (isTRUE(ncol(x) == 2L)) {
 
@@ -227,7 +205,6 @@ cor.phi <- function(x, adjust = FALSE, tri = c("both", "lower", "upper"),
 
       }
 
-    #.................
     # If not two dichotomous variables
     } else {
 
@@ -235,15 +212,13 @@ cor.phi <- function(x, adjust = FALSE, tri = c("both", "lower", "upper"),
 
     }
 
-  #----------------------------------------
-  # More than two variables
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## More than two variables ####
   } else {
 
-    #......
     # Pairwise combination
     comb.n <- combn(ncol(x), m = 2L)
 
-    #......
     # Compute all pairwise contingency coefficients
     comb.n.phi <- rep(NA, times = ncol(comb.n))
     for (i in seq_len(ncol(comb.n))) {
@@ -252,26 +227,23 @@ cor.phi <- function(x, adjust = FALSE, tri = c("both", "lower", "upper"),
 
     }
 
-    #......
     # Contingency coefficient matrix
     phi <- matrix(NA, ncol = ncol(x), nrow = ncol(x), dimnames = list(colnames(x), colnames(x)))
 
-    #......
     # Assign contingenfy coefficients to lower triangular
     phi[lower.tri(phi)] <- comb.n.phi
 
-    #......
     # Copy lower triangular to upper triangular
     phi[upper.tri(phi)] <- t(phi)[upper.tri(phi)]
 
-    #......
     # Set diagonal to 1
     diag(phi) <- 1L
 
   }
 
-  ####################################################################################
-  # Return object
+  #_____________________________________________________________________________
+  #
+  # Return Object --------------------------------------------------------------
 
   object <- list(call = match.call(),
                  type = "cor.phi",
@@ -282,8 +254,9 @@ cor.phi <- function(x, adjust = FALSE, tri = c("both", "lower", "upper"),
 
   class(object) <- "misty.object"
 
-  ####################################################################################
-  # Output
+  #_____________________________________________________________________________
+  #
+  # Output ---------------------------------------------------------------------
 
   if (isTRUE(output)) { print(object, check = FALSE) }
 
